Learn R Programming

openVA (version 1.2.0)

grouping_eava_child: Mapping for child causes of death to the list used by the EAVA algorithm.

Description

Intended for use when comparing assigned causes of death between the EAVA algorithm and InSilicoVA/InterVA5.

Arguments

Format

Data Frame

Details

#'

Examples

Run this code

data(grouping_eava_child)

Run the code above in your browser using DataLab